@@ -17,6 +17,7 @@ import os
 
 import dns
 import dns.resolver
+import six
 from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -24,8 +25,6 @@ from oslo_log import log as logging
 from designate.backend.agent_backend import base
 from designate import exceptions
 from designate import utils
-from designate.i18n import _LI
-
 
 LOG = logging.getLogger(__name__)
 CFG_GROUP = 'backend:agent:bind9'
@@ -62,10 +61,10 @@ class Bind9Backend(base.AgentBackend):
         return [(bind9_group, bind9_opts)]
 
     def start(self):
-        LOG.info(_LI("Started bind9 backend"))
+        LOG.info("Started bind9 backend")
 
     def find_zone_serial(self, zone_name):
-        LOG.debug("Finding %s" % zone_name)
+        LOG.debug("Finding %s", zone_name)
         resolver = dns.resolver.Resolver()
         resolver.nameservers = [cfg.CONF[CFG_GROUP].query_destination]
         try:
@@ -75,11 +74,11 @@ class Bind9Backend(base.AgentBackend):
         return rdata.serial
 
     def create_zone(self, zone):
-        LOG.debug("Creating %s" % zone.origin.to_text())
+        LOG.debug("Creating %s", zone.origin.to_text())
         self._sync_zone(zone, new_zone_flag=True)
 
     def update_zone(self, zone):
-        LOG.debug("Updating %s" % zone.origin.to_text())
+        LOG.debug("Updating %s", zone.origin.to_text())
         self._sync_zone(zone)
 
     def delete_zone(self, zone_name):
@@ -113,7 +112,9 @@ class Bind9Backend(base.AgentBackend):
 
         # NOTE: Different versions of BIND9 behave differently with a trailing
         #       dot, so we're just going to take it off.
-        zone_name = zone.origin.to_text(omit_final_dot=True).decode('utf-8')
+        zone_name = zone.origin.to_text(omit_final_dot=True)
+        if six.PY3 and isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         # NOTE: Only one thread should be working with the Zonefile at a given
         #       time. The sleep(1) below introduces a not insignificant risk
