@@ -38,12 +38,14 @@ Supported Knot versions: >= 2.1, < 3
 Configured in [service:agent:gdnsd]
 """
 
+import errno
 import os
 import tempfile
 import string
 
 import dns
 import dns.resolver
+import six
 from oslo_concurrency.processutils import ProcessExecutionError
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -51,9 +53,6 @@ from oslo_log import log as logging
 from designate import utils
 from designate import exceptions
 from designate.backend.agent_backend import base
-from designate.i18n import _LI
-from designate.i18n import _LE
-
 
 LOG = logging.getLogger(__name__)
 CFG_GROUP = 'backend:agent:gdnsd'
@@ -92,7 +91,7 @@ def filter_exceptions(fn):
         except exceptions.Backend as e:
             raise e
         except Exception as e:
-            LOG.error(_LE("Unhandled exception %s"), e, exc_info=True)
+            LOG.error("Unhandled exception %s", e, exc_info=True)
             raise exceptions.Backend(e)
 
     return wrapper
@@ -111,15 +110,15 @@ class GdnsdBackend(base.AgentBackend):
         super(GdnsdBackend, self).__init__(*a, **kw)
 
         self._gdnsd_cmd_name = cfg.CONF[CFG_GROUP].gdnsd_cmd_name
-        LOG.info(_LI("gdnsd command: %r"), self._gdnsd_cmd_name)
+        LOG.info("gdnsd command: %r", self._gdnsd_cmd_name)
         self._confdir_path = cfg.CONF[CFG_GROUP].confdir_path
         self._zonedir_path = os.path.join(self._confdir_path, 'zones')
-        LOG.info(_LI("gdnsd conf directory: %r"), self._confdir_path)
+        LOG.info("gdnsd conf directory: %r", self._confdir_path)
         self._resolver = dns.resolver.Resolver(configure=False)
         self._resolver.timeout = SOA_QUERY_TIMEOUT
         self._resolver.lifetime = SOA_QUERY_TIMEOUT
         self._resolver.nameservers = [cfg.CONF[CFG_GROUP].query_destination]
-        LOG.info(_LI("Resolvers: %r"), self._resolver.nameservers)
+        LOG.info("Resolvers: %r", self._resolver.nameservers)
         self._check_dirs(self._zonedir_path)
 
     def start(self):
@@ -127,7 +126,7 @@ class GdnsdBackend(base.AgentBackend):
 
         :raises: exception.Backend on invalid configuration
         """
-        LOG.info(_LI("Started gdnsd backend"))
+        LOG.info("Started gdnsd backend")
         self._check_conf()
 
     def _check_conf(self):
@@ -140,9 +139,11 @@ class GdnsdBackend(base.AgentBackend):
                 run_as_root=False,
             )
         except ProcessExecutionError as e:
-            LOG.error(_LE("Command output: %(out)r Stderr: %(err)r"), {
-                'out': e.stdout, 'err': e.stderr
-            })
+            LOG.error("Command output: %(out)r Stderr: %(err)r",
+                      {
+                          'out': e.stdout,
+                          'err': e.stderr
+                      })
             raise exceptions.Backend("Configuration check failed")
 
     def _check_dirs(self, *dirnames):
@@ -185,7 +186,9 @@ class GdnsdBackend(base.AgentBackend):
         """Create or update a zone file atomically.
         The zone file is written to a unique temp file and then renamed
         """
-        zone_name = zone.origin.to_text(omit_final_dot=True).decode('utf-8')
+        zone_name = zone.origin.to_text(omit_final_dot=True)
+        if six.PY3 and isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
         zone_base_fname = self._generate_zone_filename(zone_name)
         zone_fname = os.path.join(self._zonedir_path, zone_base_fname)
         try:
@@ -246,7 +249,7 @@ class GdnsdBackend(base.AgentBackend):
             os.remove(zone_fn)
             LOG.debug('Deleted Zone: %s', zone_name)
         except OSError as e:
-            if os.errno.ENOENT == e.errno:
-                LOG.info(_LI("Zone datafile %s was already deleted"), zone_fn)
+            if errno.ENOENT == e.errno:
+                LOG.info("Zone datafile %s was already deleted", zone_fn)
                 return
             raise
