@@ -20,14 +20,12 @@ from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 import debtcollector
 
-from designate.i18n import _LE
 from designate import service
 from designate import utils
 from designate import version
 from designate import hookpoints
 from designate.pool_manager import service as pool_manager_service
 
-
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 CONF.import_opt('workers', 'designate.pool_manager',
@@ -45,10 +43,10 @@ def main():
     # NOTE(timsim): This is to ensure people don't start the wrong
     #               services when the worker model is enabled.
     if cfg.CONF['service:worker'].enabled:
-        LOG.error(_LE('You have designate-worker enabled, starting '
-                      'designate-pool-manager is incompatible with '
-                      'designate-worker. You need to start '
-                      'designate-worker instead.'))
+        LOG.error('You have designate-worker enabled, starting '
+                  'designate-pool-manager is incompatible with '
+                  'designate-worker. You need to start '
+                  'designate-worker instead.')
         sys.exit(1)
 
     debtcollector.deprecate('designate-pool-manager is deprecated in favor of '
