@@ -20,14 +20,13 @@ import dns.rcode
 import dns.rdataclass
 import dns.rdatatype
 import dns.message
+import six
 from oslo_config import cfg
 from oslo_log import log as logging
 
 from designate import exceptions
 from designate.mdns import xfr
 from designate.central import rpcapi as central_api
-from designate.i18n import _LI
-from designate.i18n import _LW
 
 
 LOG = logging.getLogger(__name__)
@@ -66,7 +65,7 @@ class RequestHandler(xfr.XFRMixin):
                     request.question[0].rdclass != dns.rdataclass.IN):
                 LOG.debug("Refusing due to numbers of questions or rdclass")
                 yield self._handle_query_error(request, dns.rcode.REFUSED)
-                raise StopIteration
+                return
 
             q_rrset = request.question[0]
             # Handle AXFR and IXFR requests with an AXFR responses for now.
@@ -75,23 +74,23 @@ class RequestHandler(xfr.XFRMixin):
             if q_rrset.rdtype in (dns.rdatatype.AXFR, dns.rdatatype.IXFR):
                 for response in self._handle_axfr(request):
                     yield response
-                raise StopIteration
+                return
 
             else:
                 for response in self._handle_record_query(request):
                     yield response
-                raise StopIteration
+                return
 
         elif request.opcode() == dns.opcode.NOTIFY:
             for response in self._handle_notify(request):
                 yield response
-            raise StopIteration
+            return
 
         else:
             # Unhandled OpCode's include STATUS, IQUERY, UPDATE
             LOG.debug("Refusing unhandled opcode")
             yield self._handle_query_error(request, dns.rcode.REFUSED)
-            raise StopIteration
+            return
 
     def _handle_notify(self, request):
         """
@@ -108,12 +107,16 @@ class RequestHandler(xfr.XFRMixin):
         if len(request.question) != 1:
             response.set_rcode(dns.rcode.FORMERR)
             yield response
-            raise StopIteration
+            return
         else:
             question = request.question[0]
 
+        name = question.name.to_text()
+        if six.PY3 and isinstance(name, bytes):
+            name = name.decode('utf-8')
+
         criterion = {
-            'name': question.name.to_text().decode('utf-8'),
+            'name': name,
             'type': 'SECONDARY',
             'deleted': False
         }
@@ -123,7 +126,7 @@ class RequestHandler(xfr.XFRMixin):
         except exceptions.ZoneNotFound:
             response.set_rcode(dns.rcode.NOTAUTH)
             yield response
-            raise StopIteration
+            return
 
         notify_addr = request.environ['addr'][0]
 
@@ -132,12 +135,11 @@ class RequestHandler(xfr.XFRMixin):
         # We'll reply but don't do anything with the NOTIFY.
         master_addr = zone.get_master_by_ip(notify_addr)
         if not master_addr:
-            msg = _LW("NOTIFY for %(name)s from non-master server "
-                      "%(addr)s, refusing.")
-            LOG.warning(msg % {"name": zone.name, "addr": notify_addr})
+            LOG.warning("NOTIFY for %(name)s from non-master server %(addr)s, "
+                        "refusing.", {"name": zone.name, "addr": notify_addr})
             response.set_rcode(dns.rcode.REFUSED)
             yield response
-            raise StopIteration
+            return
 
         resolver = dns.resolver.Resolver()
         # According to RFC we should query the server that sent the NOTIFY
@@ -146,20 +148,18 @@ class RequestHandler(xfr.XFRMixin):
         soa_answer = resolver.query(zone.name, 'SOA')
         soa_serial = soa_answer[0].serial
         if soa_serial == zone.serial:
-            msg = _LI("Serial %(serial)s is the same for master and us for "
-                      "%(zone_id)s")
-            LOG.info(msg, {"serial": soa_serial, "zone_id": zone.id})
+            LOG.info("Serial %(serial)s is the same for master and us for "
+                     "%(zone_id)s", {"serial": soa_serial, "zone_id": zone.id})
         else:
-            msg = _LI("Scheduling AXFR for %(zone_id)s from %(master_addr)s")
-            info = {"zone_id": zone.id, "master_addr": master_addr}
-            LOG.info(msg, info)
+            LOG.info("Scheduling AXFR for %(zone_id)s from %(master_addr)s",
+                     {"zone_id": zone.id, "master_addr": master_addr})
             self.tg.add_thread(self.zone_sync, context, zone,
                                [master_addr])
 
         response.flags |= dns.flags.AA
 
         yield response
-        raise StopIteration
+        return
 
     def _handle_query_error(self, request, rcode):
         """
@@ -228,23 +228,26 @@ class RequestHandler(xfr.XFRMixin):
         # TODO(vinod) once validation is separated from the api,
         # validate the parameters
         try:
+            name = q_rrset.name.to_text()
+            if six.PY3 and isinstance(name, bytes):
+                name = name.decode('utf-8')
             criterion = self._zone_criterion_from_request(
-                request, {'name': q_rrset.name.to_text().decode('utf-8')})
+                request, {'name': name})
             zone = self.storage.find_zone(context, criterion)
 
         except exceptions.ZoneNotFound:
-            LOG.warning(_LW("ZoneNotFound while handling axfr request. "
-                            "Question was %(qr)s") % {'qr': q_rrset})
+            LOG.warning("ZoneNotFound while handling axfr request. "
+                        "Question was %(qr)s", {'qr': q_rrset})
 
             yield self._handle_query_error(request, dns.rcode.REFUSED)
-            raise StopIteration
+            return
 
         except exceptions.Forbidden:
-            LOG.warning(_LW("Forbidden while handling axfr request. "
-                            "Question was %(qr)s") % {'qr': q_rrset})
+            LOG.warning("Forbidden while handling axfr request. "
+                        "Question was %(qr)s", {'qr': q_rrset})
 
             yield self._handle_query_error(request, dns.rcode.REFUSED)
-            raise StopIteration
+            return
 
         # The AXFR response needs to have a SOA at the beginning and end.
         criterion = {'zone_id': zone.id, 'type': 'SOA'}
@@ -267,8 +270,7 @@ class RequestHandler(xfr.XFRMixin):
         max_message_size = CONF['service:mdns'].max_message_size
 
         if max_message_size > 65535:
-            LOG.warning(_LW('MDNS max message size must not be greater than '
-                            '65535'))
+            LOG.warning('MDNS max message size must not be greater than 65535')
             max_message_size = 65535
 
         if request.had_tsig:
@@ -304,15 +306,15 @@ class RequestHandler(xfr.XFRMixin):
                 if renderer.counts[dns.renderer.ANSWER] == 0:
                     # We've received a TooBig from the first attempted RRSet in
                     # this packet. Log a warning and abort the AXFR.
-                    LOG.warning(_LW('Aborted AXFR of %(zone)s, a single RR '
-                                    '(%(rrset_type)s %(rrset_name)s) '
-                                    'exceeded the max message size.'),
+                    LOG.warning('Aborted AXFR of %(zone)s, a single RR '
+                                '(%(rrset_type)s %(rrset_name)s) '
+                                'exceeded the max message size.',
                                 {'zone': zone.name,
                                  'rrset_type': record[1],
                                  'rrset_name': record[3]})
 
                     yield self._handle_query_error(request, dns.rcode.SERVFAIL)
-                    raise StopIteration
+                    return
 
                 else:
                     yield self._finalize_packet(renderer, request)
@@ -321,7 +323,7 @@ class RequestHandler(xfr.XFRMixin):
         if renderer is not None:
             yield self._finalize_packet(renderer, request)
 
-        raise StopIteration
+        return
 
     def _finalize_packet(self, renderer, request):
         renderer.write_header()
@@ -346,10 +348,13 @@ class RequestHandler(xfr.XFRMixin):
 
         try:
             q_rrset = request.question[0]
+            name = q_rrset.name.to_text()
+            if six.PY3 and isinstance(name, bytes):
+                name = name.decode('utf-8')
             # TODO(vinod) once validation is separated from the api,
             # validate the parameters
             criterion = {
-                'name': q_rrset.name.to_text().decode('utf-8'),
+                'name': name,
                 'type': dns.rdatatype.to_text(q_rrset.rdtype),
                 'zones_deleted': False
             }
@@ -372,16 +377,16 @@ class RequestHandler(xfr.XFRMixin):
             #
             # To simply things currently this returns a REFUSED in all cases.
             # If zone transfers needs different errors, we could revisit this.
-            LOG.info(_LI("NotFound, refusing. Question was %(qr)s"),
+            LOG.info("NotFound, refusing. Question was %(qr)s",
                      {'qr': q_rrset})
             yield self._handle_query_error(request, dns.rcode.REFUSED)
-            raise StopIteration
+            return
 
         except exceptions.Forbidden:
-            LOG.info(_LI("Forbidden, refusing. Question was %(qr)s"),
+            LOG.info("Forbidden, refusing. Question was %(qr)s",
                      {'qr': q_rrset})
             yield self._handle_query_error(request, dns.rcode.REFUSED)
-            raise StopIteration
+            return
 
         try:
             criterion = self._zone_criterion_from_request(
@@ -389,16 +394,16 @@ class RequestHandler(xfr.XFRMixin):
             zone = self.storage.find_zone(context, criterion)
 
         except exceptions.ZoneNotFound:
-            LOG.warning(_LW("ZoneNotFound while handling query request"
-                            ". Question was %(qr)s") % {'qr': q_rrset})
+            LOG.warning("ZoneNotFound while handling query request. "
+                        "Question was %(qr)s", {'qr': q_rrset})
             yield self._handle_query_error(request, dns.rcode.REFUSED)
-            raise StopIteration
+            return
 
         except exceptions.Forbidden:
-            LOG.warning(_LW("Forbidden while handling query request. "
-                            "Question was %(qr)s") % {'qr': q_rrset})
+            LOG.warning("Forbidden while handling query request. "
+                        "Question was %(qr)s", {'qr': q_rrset})
             yield self._handle_query_error(request, dns.rcode.REFUSED)
-            raise StopIteration
+            return
 
         r_rrset = self._convert_to_rrset(zone, recordset)
         response.answer = [r_rrset] if r_rrset else []
