@@ -18,6 +18,7 @@ from sqlalchemy import (Table, MetaData, Column, String, Text, Integer,
                         UniqueConstraint, ForeignKeyConstraint)
 
 from oslo_config import cfg
+from oslo_db.sqlalchemy import types
 from oslo_utils import timeutils
 
 from designate import utils
@@ -28,7 +29,8 @@ CONF = cfg.CONF
 
 RESOURCE_STATUSES = ['ACTIVE', 'PENDING', 'DELETED', 'ERROR']
 RECORD_TYPES = ['A', 'AAAA', 'CNAME', 'MX', 'SRV', 'TXT', 'SPF', 'NS', 'PTR',
-                'SSHFP']
+                'SSHFP', 'SOA', 'NAPTR', 'CAA']
+
 TASK_STATUSES = ['ACTIVE', 'PENDING', 'DELETED', 'ERROR', 'COMPLETE']
 TSIG_ALGORITHMS = ['hmac-md5', 'hmac-sha1', 'hmac-sha224', 'hmac-sha256',
                    'hmac-sha384', 'hmac-sha512']
@@ -39,11 +41,14 @@ ACTIONS = ['CREATE', 'DELETE', 'UPDATE', 'NONE']
 ZONE_TYPES = ('PRIMARY', 'SECONDARY',)
 ZONE_TASK_TYPES = ['IMPORT', 'EXPORT']
 
+SERVICE_STATES = [
+    "UP", "DOWN", "WARNING"
+]
 
 metadata = MetaData()
 
 # TODO(Federico) some default column values are not needed because we
-# explicitely set the value on record insertion. Having default values could
+# explicitly set the value on record insertion. Having default values could
 # hide bugs.
 
 
@@ -51,6 +56,25 @@ def default_shard(context, id_col):
     return int(context.current_parameters[id_col][0:3], 16)
 
 
+service_status = Table("service_statuses", metadata,
+    Column('id', UUID, default=utils.generate_uuid, primary_key=True),
+    Column('created_at', DateTime, default=lambda: timeutils.utcnow()),
+    Column('updated_at', DateTime, onupdate=lambda: timeutils.utcnow()),
+
+    Column('service_name', String(40), nullable=False),
+    Column('hostname', String(255), nullable=False),
+    Column('heartbeated_at', DateTime, nullable=True),
+
+    Column('status', Enum(name='service_statuses', *SERVICE_STATES),
+           nullable=False),
+    Column('stats', types.JsonEncodedDict, nullable=False),
+    Column('capabilities', types.JsonEncodedDict, nullable=False),
+
+    mysql_engine='InnoDB',
+    mysql_charset='utf8',
+)
+
+
 quotas = Table('quotas', metadata,
     Column('id', UUID, default=utils.generate_uuid, primary_key=True),
     Column('version', Integer, default=1, nullable=False),
@@ -105,7 +129,7 @@ zones = Table('zones', metadata,
     Column('expire', Integer, default=CONF.default_soa_expire, nullable=False),
     Column('minimum', Integer, default=CONF.default_soa_minimum,
            nullable=False),
-    Column('status', Enum(name='resource_statuses', *RESOURCE_STATUSES),
+    Column('status', Enum(name='zones_resource_statuses', *RESOURCE_STATUSES),
            nullable=False, server_default='PENDING', default='PENDING'),
     Column('parent_zone_id', UUID, default=None, nullable=True),
     Column('action', Enum(name='actions', *ACTIONS),
@@ -203,7 +227,8 @@ records = Table('records', metadata,
            nullable=True),
     Column('managed_resource_id', UUID, default=None, nullable=True),
     Column('managed_tenant_id', String(36), default=None, nullable=True),
-    Column('status', Enum(name='resource_statuses', *RESOURCE_STATUSES),
+    Column('status', Enum(name='records_resource_statuses',
+                          *RESOURCE_STATUSES),
            server_default='PENDING', default='PENDING', nullable=False),
     Column('action', Enum(name='actions', *ACTIONS),
            default='CREATE', server_default='CREATE', nullable=False),
@@ -397,7 +422,8 @@ zone_transfer_requests = Table('zone_transfer_requests', metadata,
     Column("description", String(255), nullable=False),
     Column("tenant_id", String(36), default=None, nullable=False),
     Column("target_tenant_id", String(36), default=None, nullable=True),
-    Column("status", Enum(name='resource_statuses', *TASK_STATUSES),
+    Column("status", Enum(name='zone_transfer_requests_resource_statuses',
+                          *TASK_STATUSES),
            nullable=False, server_default='ACTIVE',
            default='ACTIVE'),
 
@@ -416,7 +442,8 @@ zone_transfer_accepts = Table('zone_transfer_accepts', metadata,
     Column('zone_id', UUID, nullable=False),
     Column('zone_transfer_request_id', UUID, nullable=False),
     Column("tenant_id", String(36), default=None, nullable=False),
-    Column("status", Enum(name='resource_statuses', *TASK_STATUSES),
+    Column("status", Enum(name='zone_transfer_accepts_resource_statuses',
+                          *TASK_STATUSES),
            nullable=False, server_default='ACTIVE',
            default='ACTIVE'),
 
@@ -441,7 +468,7 @@ zone_tasks = Table('zone_tasks', metadata,
     Column('task_type', Enum(name='task_types', *ZONE_TASK_TYPES),
            nullable=True),
     Column('message', String(160), nullable=True),
-    Column('status', Enum(name='resource_statuses', *TASK_STATUSES),
+    Column('status', Enum(name='zone_tasks_resource_statuses', *TASK_STATUSES),
            nullable=False, server_default='ACTIVE',
            default='ACTIVE'),
     Column('location', String(160), nullable=True),
