@@ -19,8 +19,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 
-from designate.i18n import _LI
-from designate.i18n import _LE
 from designate import backend
 from designate import exceptions
 from designate import service
@@ -35,6 +33,13 @@ LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
+class AlsoNotifyTask(object):
+    """
+    Placeholder to define options for also_notify targets
+    """
+    pass
+
+
 class Service(service.RPCService, service.Service):
     RPC_API_VERSION = '1.0'
 
@@ -51,7 +56,7 @@ class Service(service.RPCService, service.Service):
             # Fetch an instance of the Backend class
             target.backend = backend.get_backend(target)
 
-        LOG.info(_LI('%d targets setup'), len(pool.targets))
+        LOG.info('%d targets setup', len(pool.targets))
 
         if len(pool.targets) == 0:
             raise exceptions.NoPoolTargetsConfigured()
@@ -72,12 +77,12 @@ class Service(service.RPCService, service.Service):
                 if len(pool.targets) > 0:
                     has_targets = True
                 else:
-                    LOG.error(_LE("No targets for %s found."), pool)
+                    LOG.error("No targets for %s found.", pool)
                     time.sleep(5)
 
             # Pool data may not have migrated to the DB yet
             except exceptions.PoolNotFound:
-                LOG.error(_LE("Pool ID %s not found."), pool_id)
+                LOG.error("Pool ID %s not found.", pool_id)
                 time.sleep(5)
             # designate-central service may not have started yet
             except messaging.exceptions.MessagingTimeout:
@@ -111,20 +116,30 @@ class Service(service.RPCService, service.Service):
 
     def get_pool(self, pool_id):
         if pool_id not in self.pools_map:
-            LOG.info(_LI("Lazily loading pool %s"), pool_id)
+            LOG.info("Lazily loading pool %s", pool_id)
             self.pools_map[pool_id] = self.load_pool(pool_id)
         return self.pools_map[pool_id]
 
     def start(self):
         super(Service, self).start()
-        LOG.info(_LI('Started worker'))
+        LOG.info('Started worker')
 
     def _do_zone_action(self, context, zone):
         pool = self.get_pool(zone.pool_id)
-        task = zonetasks.ZoneAction(
+        all_tasks = []
+        all_tasks.append(zonetasks.ZoneAction(
             self.executor, context, pool, zone, zone.action
-        )
-        return self.executor.run(task)
+        ))
+
+        # Send a NOTIFY to each also-notifies
+        for also_notify in pool.also_notifies:
+            notify_target = AlsoNotifyTask()
+            notify_target.options = {'host': also_notify.host,
+                                     'port': also_notify.port}
+            all_tasks.append(zonetasks.SendNotify(self.executor,
+                                                  zone,
+                                                  notify_target))
+        return self.executor.run(all_tasks)
 
     def create_zone(self, context, zone):
         """
